## dbt-tests-adapter 1.19.5 - December 09, 2025

### Features

- Add inheritable tests for testing function default argument support ([#1442](https://github.com/dbt-labs/dbt-adapters/issues/1442))
- Add support for py3.13 ([#1475](https://github.com/dbt-labs/dbt-adapters/issues/1475))
